from wheat.utils.appdirs import user_config_dir


CONFIG_DIR = user_config_dir("wheat")
